import { BasicApi } from '@/apis/basic';
import { create } from 'zustand';

interface BasicDataState {
  inited: boolean;

  lines: BasicData.Predefine[];
  jobs: BasicData.Job[];
  departments: BasicData.Department[];
  equipments: BasicData.Equipment[];
  operations: BasicData.Operation[];
  positions: BasicData.Position[];

  fetchLines: () => void;
  fetchJobs: () => void;
  fetchDepartments: () => void;
  fetchEquipments: () => void;
  fetchOperations: () => void;
  fetchPositions: () => void;

  init: () => Promise<void>;

  getDepartmentName: (id: number) => string;
  getJobName: (id: number) => string;
}


export const useBasicDataStore = create<BasicDataState>(

  (set, get) => ({
    inited: false,

    lines: [],
    jobs: [],
    departments: [],
    equipments: [],
    operations: [],
    positions: [],

    fetchLines: async () => {
      const lines = await BasicApi.getPredefineList('line');
      set({ lines });
    },
    fetchJobs: async () => {
      const jobs = await BasicApi.getJobList();
      set({ jobs });
    },
    fetchDepartments: async () => {
      const departments = await BasicApi.getDepartmentList();
      set({ departments });
    },
    fetchEquipments: async () => {
      const equipments = await BasicApi.getEquipmentList();
      set({ equipments });
    },
    fetchOperations: async () => {
      const operations = await BasicApi.getOperationList();
      set({ operations });
    },
    fetchPositions: async () => {
      const positions = await BasicApi.getPositionList();
      set({ positions });
    },


    init: async () => {
      if (get().inited) return;
      const { lines, jobs, departments, equipments, operations, positions } = get();
      if (!lines.length) await get().fetchLines();
      if (!jobs.length) await get().fetchJobs();
      if (!departments.length) await get().fetchDepartments();
      if (!equipments.length) await get().fetchEquipments();
      if (!operations.length) await get().fetchOperations();
      if (!positions.length) await get().fetchPositions();
      set({ inited: true });
    },

    getDepartmentName: (id: number) => {
      const department = get().departments.find((d) => d.id === id);
      return department?.name || '';
    },
    getJobName: (id: number) => {
      const job = get().jobs.find((j) => j.id === id);
      return job?.name || '';
    },
  }),


);
